@@ -20,15 +20,17 @@ There are three steps to this process.
 3. Importing and instantiating the actual components
 
 """
-from typing import Tuple, List, Dict, Union, Any
+from typing import Any, Dict, List, Tuple, Union
 
 from vivarium.config_tree import ConfigTree
 from vivarium.framework.utilities import import_by_path
+
 from .manager import ComponentConfigError
 
 
 class ParsingError(ComponentConfigError):
     """Error raised when component configurations are not specified correctly."""
+
     pass
 
 
@@ -88,7 +90,9 @@ class ComponentConfigurationParser:
         component_list = prep_components(component_list)
         return import_and_instantiate_components(component_list)
 
-    def parse_component_config(self, component_config: Dict[str, Union[Dict, List]]) -> List[str]:
+    def parse_component_config(
+        self, component_config: Dict[str, Union[Dict, List]]
+    ) -> List[str]:
         """Parses a hierarchical component specification into a list of
         standardized component definitions.
 
@@ -116,7 +120,9 @@ class ComponentConfigurationParser:
         return parse_component_config_to_list(component_config)
 
 
-def parse_component_config_to_list(component_config: Dict[str, Union[Dict, List]]) -> List[str]:
+def parse_component_config_to_list(
+    component_config: Dict[str, Union[Dict, List]]
+) -> List[str]:
     """Helper function for parsing hierarchical component configuration into a
     flat list.
 
@@ -162,10 +168,12 @@ def parse_component_config_to_list(component_config: Dict[str, Union[Dict, List]
 
     def _process_level(level, prefix):
         if not level:
-            raise ParsingError(f'Check your configuration. Component {prefix} should not be left empty with the header')
+            raise ParsingError(
+                f"Check your configuration. Component {prefix} should not be left empty with the header"
+            )
 
         if isinstance(level, list):
-            return ['.'.join(prefix + [child]) for child in level]
+            return [".".join(prefix + [child]) for child in level]
 
         component_list = []
         for name, child in level.items():
@@ -192,8 +200,8 @@ def prep_components(component_list: Union[List[str], Tuple[str]]) -> List[Tuple[
     """
     components = []
     for c in component_list:
-        path, args_plus = c.split('(')
-        cleaned_args = clean_args(args_plus[:-1].split(','), path)
+        path, args_plus = c.split("(")
+        cleaned_args = clean_args(args_plus[:-1].split(","), path)
         components.append((path, cleaned_args))
     return components
 
@@ -220,7 +228,9 @@ def clean_args(args: List, path: str) -> Tuple:
         if not a:
             continue
 
-        not_a_valid_string = len(a) < 3 or not ((a[0] == a[-1] == "'") or (a[0] == a[-1] == '"'))
+        not_a_valid_string = len(a) < 3 or not (
+            (a[0] == a[-1] == "'") or (a[0] == a[-1] == '"')
+        )
         if not_a_valid_string:
             raise ParsingError(f"Invalid component argument {a} for component {path}")
 
